@@ -63,6 +63,27 @@ class HttpStream(Stream, ABC):
         """
         return "GET"
 
+    @property
+    def raise_on_http_errors(self) -> bool:
+        """
+        Override if needed. If set to False, allows opting-out of raising HTTP code exception.
+        """
+        return True
+
+    @property
+    def max_retries(self) -> Union[int, None]:
+        """
+        Override if needed. Specifies maximum amount of retries for backoff policy. Return None for no limit.
+        """
+        return 5
+
+    @property
+    def retry_factor(self) -> int:
+        """
+        Override if needed. Specifies factor for backoff policy.
+        """
+        return 5
+
     @property
     def authenticator(self) -> HttpAuthenticator:
         return self._authenticator
@@ -207,13 +228,10 @@ class HttpStream(Stream, ABC):
 
         return self._session.prepare_request(requests.Request(**args))
 
-    # TODO allow configuring these parameters. If we can get this into the requests library, then we can do it without the ugly exception hacks
-    #  see https://github.com/litl/backoff/pull/122
-    @default_backoff_handler(max_tries=5, factor=5)
-    @user_defined_backoff_handler(max_tries=5)
-    def _send_request(self, request: requests.PreparedRequest, request_kwargs: Mapping[str, Any]) -> requests.Response:
+    def _send(self, request: requests.PreparedRequest, request_kwargs: Mapping[str, Any]) -> requests.Response:
         """
         Wraps sending the request in rate limit and error handlers.
+        Please note that error handling for HTTP status codes will be ignored if raise_on_http_errors is set to False
 
         This method handles two types of exceptions:
             1. Expected transient exceptions e.g: 429 status code.
@@ -230,19 +248,51 @@ class HttpStream(Stream, ABC):
         Unexpected persistent exceptions are not handled and will cause the sync to fail.
         """
         response: requests.Response = self._session.send(request, **request_kwargs)
+
         if self.should_retry(response):
             custom_backoff_time = self.backoff_time(response)
             if custom_backoff_time:
                 raise UserDefinedBackoffException(backoff=custom_backoff_time, request=request, response=response)
             else:
                 raise DefaultBackoffException(request=request, response=response)
-        else:
+        elif self.raise_on_http_errors:
             # Raise any HTTP exceptions that happened in case there were unexpected ones
-            # TODO handle ignoring errors
             response.raise_for_status()
 
         return response
 
+    def _send_request(self, request: requests.PreparedRequest, request_kwargs: Mapping[str, Any]) -> requests.Response:
+        """
+        Creates backoff wrappers which are responsible for retry logic
+        """
+
+        """
+        Backoff package has max_tries parameter that means total number of
+        tries before giving up, so if this number is 0 no calls expected to be done.
+        But for this class we call it max_REtries assuming there would be at
+        least one attempt and some retry attempts, to comply this logic we add
+        1 to expected retries attempts.
+        """
+        max_tries = self.max_retries
+        """
+        According to backoff max_tries docstring:
+            max_tries: The maximum number of attempts to make before giving
+                up ...The default value of None means there is no limit to
+                the number of tries.
+        This implies that if max_tries is excplicitly set to None there is no
+        limit to retry attempts, otherwise it is limited number of tries. But
+        this is not true for current version of backoff packages (1.8.0). Setting
+        max_tries to 0 or negative number would result in endless retry atempts.
+        Add this condition to avoid an endless loop if it hasnt been set
+        explicitly (i.e. max_retries is not None).
+        """
+        if max_tries is not None:
+            max_tries = max(0, max_tries) + 1
+
+        user_backoff_handler = user_defined_backoff_handler(max_tries=max_tries)(self._send)
+        backoff_handler = default_backoff_handler(max_tries=max_tries, factor=self.retry_factor)
+        return backoff_handler(user_backoff_handler)(request, request_kwargs)
+
     def read_records(
         self,
         sync_mode: SyncMode,
