@@ -26,10 +26,13 @@
 import json
 import os
 import pkgutil
-from typing import Dict
+from typing import Any, Dict, Mapping
 
 import pkg_resources
-from jsonschema import RefResolver
+from airbyte_cdk.logger import AirbyteLogger
+from airbyte_cdk.models import ConnectorSpecification
+from jsonschema import RefResolver, validate
+from jsonschema.exceptions import ValidationError
 
 
 class JsonSchemaResolver:
@@ -124,3 +127,18 @@ class ResourceSchemaLoader:
         if os.path.exists(shared_schemas_folder):
             return JsonSchemaResolver(shared_schemas_folder).resolve(raw_schema)
         return raw_schema
+
+
+def check_config_against_spec_or_exit(config: Mapping[str, Any], spec: ConnectorSpecification, logger: AirbyteLogger):
+    """
+    Check config object against spec. In case of spec is invalid, throws
+    an exception with validation error description.
+    :param config - config loaded from file specified over command line
+    :param spec - spec object generated by connector
+    :param logger - Airbyte logger for reporting validation error
+    """
+    spec_schema = spec.connectionSpecification
+    try:
+        validate(instance=config, schema=spec_schema)
+    except ValidationError as validation_error:
+        raise Exception("Config validation error: " + validation_error.message)
